-- Create an initial condition answer file
-- This solution has a fixed 300K applied to 
-- the boundaries of the domain.
open("T0.feh");
hi_analyze();
hi_close();

-- Load the first transient solution file.
-- The difference betweeen T0.feh and T1.feh is that
-- T1 has a different boundary condition applied to the edge
-- that will drive the temperature up to a new steady-state of 400K
open("T1.feh");
for n=1,20 do
	-- Modify to the problem definition to point to the 
	-- solution from the previous iteration. The program will step
	-- the solution forward from the previous step using an implicit
	-- Euler time integration scheme.
	-- For this particular case, a 1s time step has been selected.
	hi_probdef("inches","axi",1.e-8,1,30,"T"..(n-1)..".anh",1);
	hi_saveas("T"..n..".feh");
	hi_analyze();
	
	-- Save a screenshot of each solution so that they
	-- can be strung together into a movie
	hi_loadsolution();
	--ho showdensityplot(legend,gscale,type,upper,lower)
	ho_showdensityplot(1,0,0,400,300,0);
	ho_savebitmap("T"..n..".bmp");
	ho_close();
end
hi_close();
	